@@ -184,7 +184,9 @@ devSetLabel <- function(which=dev.cur(), label, ...) {
 # @synopsis
 #
 # \arguments{
-#   \item{which}{An index (@numeric) or a label (@character).}
+#   \item{which}{An index (@numeric) or a label (@character).
+#     If neither, then a label corresponding to the checksum of
+#     \code{which} as generated by @see "digest::digest" is used.}
 #   \item{...}{Not used.}
 # }
 #
@@ -206,12 +208,19 @@ devSet <- function(which=dev.next(), ...) {
   args <- list(...);
 
   # Argument 'which':
-  if (is.character(which)) {
-    args$label <- which;
-    which <- .devIndexOf(which, error=FALSE);
-    # If not existing, open the next available one
-    if (is.na(which))
-      which <- .devNextAvailable();
+  if (!is.numeric(which) || length(which) != 1) {
+    if (length(which) != 1 || !is.character(which)) {
+      require("digest") || throw("Package not loaded: digest");
+      which <- digest(which);
+    }
+
+    if (is.character(which)) {
+      args$label <- which;
+      which <- .devIndexOf(which, error=FALSE);
+      # If not existing, open the next available one
+      if (is.na(which))
+        which <- .devNextAvailable();
+    }
   }
 
   if (which < 2) {
@@ -338,8 +347,9 @@ devOff <- function(which=dev.cur(), ...) {
 #*/########################################################################### 
 devDone <- function(which=dev.cur(), ...) {
   # Do nothing?
-  if (which <= 1)
+  if (is.numeric(which) && length(which) == 1 && which <= 1) {
     return(invisible());
+  }
 
   which <- devSet(which);
   if (which != 1) {
@@ -483,6 +493,10 @@ devNew <- function(type=getOption("device"), ..., label=NULL) {
 
 ############################################################################
 # HISTORY: 
+# 2008-10-26
+# o Now argument 'which' to devSet() can be any object.  If not a single
+#   numeric or a single character string, then a checksum character string
+#   is generated using digest::digest(which).
 # 2008-10-16
 # o Now devDone(which=1) does nothing.  Before it gave an error.
 # o BUG FIX: Argument 'type' of devNew() did not take function:s.
